==> docx4j-openxml-objects-8.2.9-sources.jar: org/docx4j/com/microsoft/schemas/office/drawing/x2014/chart/CTChartDataPointUniqueIDMap.java <==

package org.docx4j.com.microsoft.schemas.office.drawing.x2014.chart;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_ChartDataPointUniqueIDMap complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_ChartDataPointUniqueIDMap"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="ptentry" type="{http://schemas.microsoft.com/office/drawing/2014/chart}CT_ChartDataPointUniqueIDMapEntry" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_ChartDataPointUniqueIDMap", propOrder = {
    "ptentry"
})
public class CTChartDataPointUniqueIDMap implements Child
{

    protected List<CTChartDataPointUniqueIDMapEntry> ptentry;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the ptentry property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the ptentry property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getPtentry().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTChartDataPointUniqueIDMapEntry }
     * 
     * 
     */
    public List<CTChartDataPointUniqueIDMapEntry> getPtentry() {
        if (ptentry == null) {
            ptentry = new ArrayList<CTChartDataPointUniqueIDMapEntry>();
        }
        return this.ptentry;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}

==> docx4j-openxml-objects-11.4.7-sources.jar: org/docx4j/com/microsoft/schemas/office/drawing/x2014/chart/CTChartDataPointUniqueIDMap.java <==

package org.docx4j.com.microsoft.schemas.office.drawing.x2014.chart;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.Unmarshaller;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlTransient;
import jakarta.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_ChartDataPointUniqueIDMap complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_ChartDataPointUniqueIDMap"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="ptentry" type="{http://schemas.microsoft.com/office/drawing/2014/chart}CT_ChartDataPointUniqueIDMapEntry" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_ChartDataPointUniqueIDMap", propOrder = {
    "ptentry"
})
public class CTChartDataPointUniqueIDMap implements Child
{

    protected List<CTChartDataPointUniqueIDMapEntry> ptentry;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the ptentry property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the ptentry property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getPtentry().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTChartDataPointUniqueIDMapEntry }
     * 
     * 
     */
    public List<CTChartDataPointUniqueIDMapEntry> getPtentry() {
        if (ptentry == null) {
            ptentry = new ArrayList<CTChartDataPointUniqueIDMapEntry>();
        }
        return this.ptentry;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}
